Enum LogLevelColor
Source pub enum LogLevelColor {
Emergency = 16_711_850,
Alert = 16_755_200,
Critical = 9_044_223,
Error = 16_711_680,
Warn = 16_776_960,
Info = 65_280,
Debug = 255,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.