fn kprint(
state: &mut IrqMutexGuard<'static, KernelPrintState>,
string: &str,
color: Option<u32>,
)Expand description
Write string to the ring buffer, serial port, and framebuffer (if each is initialized).
fn kprint(
state: &mut IrqMutexGuard<'static, KernelPrintState>,
string: &str,
color: Option<u32>,
)Write string to the ring buffer, serial port, and framebuffer (if each is initialized).