fn write_log_buf(state: &mut KernelPrintState, s: &str)Expand description
Append s to the ring buffer, advancing the tail when the head laps it.
fn write_log_buf(state: &mut KernelPrintState, s: &str)Append s to the ring buffer, advancing the tail when the head laps it.