KernelPrintState

Struct KernelPrintState 

struct KernelPrintState {
    log_buf: [u8; 65535],
    log_head: usize,
    log_tail: usize,
    cursor_x: usize,
    cursor_y: usize,
}
All mutable state for the kprint subsystem, protected by an IrqMutex.

Fields

log_buf: [u8; 65535]

Circular byte buffer holding the most recent log output.

log_head: usize

Index of the next byte to write into log_buf.

log_tail: usize

Index of the oldest readable byte in log_buf.

cursor_x: usizecursor_y: usize