Struct KernelWriter
Source pub struct KernelWriter {
lock: IrqMutexGuard<'static, KernelPrintState>,
}
RAII handle that holds the KPRINT_STATE lock for one kprint! call, preventing interleaved output.
Write string with an optional color to all active output sinks.
Writes a string slice into this writer, returning whether the write
succeeded.
Read more
Writes a [
char] into this writer, returning whether the write succeeded.
Read more
Glue for usage of the [
write!] macro with implementors of this trait.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.